@@ -10,10 +10,10 @@ print("Welcome to F61D")
 
 help_cont = {}
 help_cont[0] = 'help     : See this help page'
-help_cont[1] = 'fuckStar : One Button to fuck Satellite'
+help_cont[1] = 'fuckstar : One Button to fuck Satellite'
 help_cont[2] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
-help_cont[4] = 'func4'
+help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'func5'
 
 
@@ -54,14 +54,20 @@ def paint():
     from f61d.bingdwendwen import draw
     draw()
     
-def func4():
-    print('func4')
+def b64tofile():
+    f1 = input('input file name:')
+    f2 = input('Output file name:')
+    f = open(f1,'rb').read()
+    from base64 import b64decode
+    df = b64decode(f)
+    with open(f2,'wb') as ff:
+        ff.write(df)
     
 def func5():
     print('func5')
 
 def main():
-    lifeGame()
+    b64tofile()
 
 if __name__ == '__main__':
     main()
